@@ -21,7 +21,7 @@ def User_Fetch(request):
 
 
 @JsonResponseWithException(printing=False)
-def User_Fetch3(request):
+def User_FetchExclBots(request):
     return JsonResponse(
         DSResponse(
             request=request,
